==> dretools-0.0.1.6.tar.gz: dretools-0.0.1.6/setup.py <==
from __future__ import print_function
from setuptools import setup, find_packages
import io

if __name__ == "__main__":

    # from http://www.jeffknupp.com/blog/2013/08/16/open-sourcing-a-python-project-the-right-way/
    def read(*file_names, **kwargs):
        encoding = kwargs.get('encoding', 'utf-8')
        sep = kwargs.get('sep', '\n')
        buf = []
        for filename in file_names:
            with io.open(filename, encoding=encoding) as f:
                buf.append(f.read())
        return sep.join(buf)

    long_description = read('README.txt')

    # MAJOR version when they make incompatible API changes,
    # MINOR version when they add functionality in a backwards-compatible manner, and
    # MAINTENANCE version when they make backwards-compatible bug fixes.
    # http://semver.org/
    setup(
        name="dretools",
        version="0.0.1.6",
        author='Tyler Weirick',
        author_email='tyler.weirick@gmail.com',
        packages=find_packages(),
        license='MIT',
        url="https://bitbucket.org/dretools/dretools",
        description='A software package for finding differential RNA editing.',
        long_description=long_description,
        platforms='any',
        scripts=['dretools/dretools.py'],
        classifiers=(
            "Programming Language :: Python :: 3",
            "License :: OSI Approved :: MIT License",
            "Operating System :: OS Independent",
        ),
        install_requires=[
            # Used with the program.
            'numpy>=1.9.2',
            'rpy2>=2.9.3',
            'scipy>=0.16.0',
            'statsmodels>=0.8.0',
            'intervaltree>=2.1.0',
            'scikit-learn>=0.16.1',
            'pysam>=0.9.1.4',
            'pandas>=0.19.0',
            # For testing.
            'behave',
            # 'mock'
        ]
    )

==> dretools-0.0.1.7.tar.gz: dretools-0.0.1.7/setup.py <==
from __future__ import print_function
from setuptools import setup, find_packages
import io

if __name__ == "__main__":

    # from http://www.jeffknupp.com/blog/2013/08/16/open-sourcing-a-python-project-the-right-way/
    def read(*file_names, **kwargs):
        encoding = kwargs.get('encoding', 'utf-8')
        sep = kwargs.get('sep', '\n')
        buf = []
        for filename in file_names:
            with io.open(filename, encoding=encoding) as f:
                buf.append(f.read())
        return sep.join(buf)

    long_description = read('README.txt')

    # MAJOR version when they make incompatible API changes,
    # MINOR version when they add functionality in a backwards-compatible manner, and
    # MAINTENANCE version when they make backwards-compatible bug fixes.
    # http://semver.org/
    setup(
        name="dretools",
        version="0.0.1.7",
        author='Tyler Weirick',
        author_email='tyler.weirick@gmail.com',
        packages=find_packages(),
        license='MIT',
        url="https://bitbucket.org/dretools/dretools",
        description='A software package for finding differential RNA editing.',
        long_description=long_description,
        platforms='any',
        scripts=['dretools'],
        classifiers=(
            "Programming Language :: Python :: 3",
            "License :: OSI Approved :: MIT License",
            "Operating System :: OS Independent",
        ),
        install_requires=[
            # Used with the program.
            'numpy>=1.9.2',
            'rpy2>=2.9.3',
            'scipy>=0.16.0',
            'statsmodels>=0.8.0',
            'intervaltree>=2.1.0',
            'scikit-learn>=0.16.1',
            'pysam>=0.9.1.4',
            'pandas>=0.19.0',
            # For testing.
            'behave',
            # 'mock'
        ]
    )
